@@ -1,4 +1,5 @@
 from .sentence import (
     Atomic, Invert, Conjunction, Disjunction, Implication, Equality
 )
-from .parse import parse
\ No newline at end of file
+from .parse import parse_sentences
+from .inference import Inference, is_contradictory
